==> atmosphere-portable-runtime-0.1-sources.jar: org/atmosphere/container/GlassFishv3CometSupport.java <==
/*
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.container;

import java.util.Map;
import org.atmosphere.cpr.AtmosphereServlet.AtmosphereHandlerWrapper;

/** 
 * Comet Portable Runtime implementation on top of Glassfish v3.
 *
 * @author Jeanfrancois Arcand
 */
public class GlassFishv3CometSupport extends GrizzlyCometSupport {

    public GlassFishv3CometSupport(Map<String,AtmosphereHandlerWrapper> atmosphereHandlers){
        super(atmosphereHandlers);
        setWebServerName(getContainerName() + "-" + getContainerDottedVersion());
    }
 
    /**
     * {@inheritDoc}
     */
    @Override
    public String getContainerName() {
        return "GlassFish";
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public String getContainerDottedVersion() {
        return "v3";
    }

    
}

==> atmosphere-portable-runtime-0.2-sources.jar: org/atmosphere/container/GlassFishv3CometSupport.java <==
/*
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.container;

import org.atmosphere.cpr.AtmosphereServlet.AtmosphereConfig;

/** 
 * Comet Portable Runtime implementation on top of Glassfish v3.
 *
 * @author Jeanfrancois Arcand
 */
public class GlassFishv3CometSupport extends GrizzlyCometSupport {

    public GlassFishv3CometSupport(AtmosphereConfig config){
        super(config);
    }
 
    /**
     * {@inheritDoc}
     */
    @Override
    public String getContainerName() {
        return "GlassFish";
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public String getContainerDottedVersion() {
        return "v3";
    }

    
}
